package com.informit.articleservice;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.servlet.ModelAndView;

import com.informit.articleservice.model.Article;
import com.informit.articleservice.model.Category;
import com.informit.articleservice.service.ArticleService;

/**
 * Spring MVC controller for processing RESTful web service requests for the article service
 * 
 * @author shaines
 */
@Controller
public class ArticleController
{
	/**
	 * Provides access to article business methods
	 */
	@Autowired
	private ArticleService articleService;
	
	@RequestMapping( value="/article/{category}/{id}", method=RequestMethod.GET )
	public ModelAndView loadArticle( @PathVariable String category,
									 @PathVariable int id,
									 @RequestParam( value="mode", required=false ) String mode ) 
	{
		// Load the article based on the mode
		Article article = null;
		if( mode != null && mode.equalsIgnoreCase( "summary" ) )
		{
			article = articleService.getArticleSummary( category, id );
		}
		else
		{
			article = articleService.getArticle( category, id );
		}
		
		// Create and return a ModelAndView that presents the article to the caller
		ModelAndView mav = new ModelAndView( "articleXmlView", BindingResult.MODEL_KEY_PREFIX + "article", article );
		return mav;
	}
	
	@RequestMapping( value="/article", method=RequestMethod.GET )
	public ModelAndView loadArticleCategories() 
	{
		List<Category> categories = articleService.loadCategories();
		
		// Create and return a ModelAndView that presents the article to the caller
		ModelAndView mav = new ModelAndView( "articleXmlView", BindingResult.MODEL_KEY_PREFIX + "article", categories );
		return mav;
	}

}
