package com.informit.articleservice.service;

import java.util.List;

import com.informit.articleservice.model.Article;
import com.informit.articleservice.model.Category;

/**
 * Defines the business methods for interacting with articles
 * 
 * @author shaines
 */
public interface ArticleService
{
	/**
	 * Returns a fully populated article
	 * 
	 * @param category		The article category
	 * @param id			The article id
	 * 
	 * @return				A fully populated article
	 */
	public Article getArticle( String category, int id );
	
	/**
	 * Returns an article that contains only the summary, no body.
	 * 
	 * @param category		The article category
	 * @param id			The article id
	 * 
	 * @return				An article that contains only a summary and no body
	 */
	public Article getArticleSummary( String category, int id );
	
	/**
	 * Returns a list of article categories
	 * 
	 * @return				A List of article categories
	 */
	public List<Category> loadCategories();
}
