package com.informit.articleservice.service;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

import org.springframework.stereotype.Service;

import com.informit.articleservice.model.Article;
import com.informit.articleservice.model.Category;

/**
 * Implements the business methods for interacting with articles
 * 
 * @author shaines
 */
@Service( "articleService" )
public class ArticleServiceImpl implements ArticleService
{
	/**
	 * Returns a fully populated article
	 * 
	 * @param category		The article category
	 * @param id			The article id
	 * 
	 * @return				A fully populated article
	 */
	@Override
	public Article getArticle( String category, int id )
	{
		return new Article( 1,
							"My Article",
							"Steven Haines",
							new Date(),
							"A facinating article",
							"Wow, aren't you enjoying this article?" );
		
	}
	
	/**
	 * Returns an article that contains only the summary, no body.
	 * 
	 * @param category		The article category
	 * @param id			The article id
	 * 
	 * @return				An article that contains only a summary and no body
	 */
	@Override
	public Article getArticleSummary( String category, int id )
	{
		return new Article( 1,
				           "My Article",
				           "Steven Haines",
				           new Date(),
						   "A facinating article" );
	}
	
	/**
	 * Returns a list of article categories
	 * 
	 * @return				A List of article categories
	 */
	public List<Category> loadCategories()
	{
		List<Category> categories = new ArrayList<Category>();
		categories.add( new Category( "fun" ) );
		categories.add( new Category( "work" ) );
		return categories;
	}


}
